netapp_ontap.models.aggregate_space API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_space`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateSpaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `block_storage GET POST PATCH`

    The block_storage field of the aggregate_space.

  `cloud_storage GET POST PATCH`

    The cloud_storage field of the aggregate_space.

  `efficiency GET POST PATCH`

    The efficiency field of the aggregate_space.

  `efficiency_without_snapshots GET POST PATCH`

    The efficiency_without_snapshots field of the aggregate_space.

  `footprint GET`

    A summation of volume footprints (including volume guarantees), in bytes. This includes all of the volume footprints in the block_storage tier and the cloud_storage tier. This is an advanced property; there is an added cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either footprint or **.

    Example: 608896